import 'package:Straznik/providers/history/historyList.dart';
import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/providers/warn_providers/torch_provider.dart';
import 'package:Straznik/providers/warn_providers/vibration_provider.dart';
import 'package:Straznik/screens/history/alarm_details_screen.dart';
import 'package:Straznik/screens/history/history_screen.dart';
import 'package:Straznik/screens/settings/phone/phone_settings_screen.dart';
import 'package:Straznik/screens/settings/phone/phone_timer_settings.dart';
import 'package:Straznik/screens/settings/settings_screen.dart';
import 'package:Straznik/screens/settings/smartband/smartband_settings_screen.dart';
import 'package:Straznik/screens/settings/smartband/smartband_timer_screen.dart';
import 'package:Straznik/screens/straznik/straznik_screen.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:splash_screen_view/SplashScreenView.dart';

import 'screens/main_screen.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Widget startScreen = Semantics(
      label: "Ekran startowy aplikacji Strażnik",
      child: SplashScreenView(
        home: MainScreen(),
        duration: 2000,
        imageSize: 200,
        imageSrc: "assets/strazniklogo.png",
        textStyle: TextStyle(
          fontSize: 30.0,
        ),
        backgroundColor: Color.fromRGBO(255, 208, 0, 1),
      ),
    );
    return MultiProvider(
      providers: [
        ChangeNotifierProvider(
          create: (_) => HistoryList(),
        ),
        ChangeNotifierProvider(
          create: (_) => TorchProvider(),
        ),
        ChangeNotifierProvider(
          create: (_) => VibrationProvider(),
        ),
        ChangeNotifierProvider(
          create: (_) => Phone(),
        ),
        ChangeNotifierProvider(
          create: (_) => NotificationProvider(),
        ),
      ],
      child: MaterialApp(
        title: 'Strażnik',
        theme: ThemeData(
          primarySwatch: Colors.yellow,
          accentColor: Colors.black,
          primaryColor: Color.fromRGBO(255, 208, 0, 1),
          buttonColor: Color.fromRGBO(0, 148, 0, 1),
          errorColor: Color.fromRGBO(196, 0, 0, 1),
          disabledColor: Color.fromRGBO(126, 130, 145, 1),
          cardColor: Color.fromRGBO(242, 210, 114, 1),
          fontFamily: 'Lato',
        ),
        home: startScreen,
        routes: {
          MainScreen.routeName: (ctx) => MainScreen(),
          HistoryScreen.routeName: (ctx) => HistoryScreen(),
          PhoneSettingsScreen.routeName: (ctx) => PhoneSettingsScreen(),
          SettingsScreen.routeName: (ctx) => SettingsScreen(),
          StraznikScreen.routeName: (ctx) => StraznikScreen(),
          PhoneTimerSettingsScreen.routeName: (ctx) =>
              PhoneTimerSettingsScreen(),
          AlarmDetailsScreen.routeName: (ctx) => AlarmDetailsScreen(),
          SmartbandSettingsScreen.routeName: (ctx) => SmartbandSettingsScreen(),
          SmartbandTimerScreen.routeName: (ctx) => SmartbandTimerScreen(),
        },
      ),
    );
  }
}
