import 'package:Straznik/helpers/db_helper.dart';
import 'package:Straznik/providers/history/history.dart';
import 'package:flutter/cupertino.dart';

class HistoryList extends ChangeNotifier {
    List<History> _historyItems= [];

    List<History> get historyItems {
      return [..._historyItems];
    }

    deleteItem(String id) {
      final existingProductIndex = _historyItems.indexWhere((prod) => prod.id == id);
      _historyItems.removeAt(existingProductIndex);
      notifyListeners();
      DBHelper.remove('history', id);
    }

    addItem(String id, String dbValue, DateTime dateTime, String description) {
      try {
        final newItem = History(id: id, dbValue: dbValue, dateTime: dateTime, description: description);
        _historyItems.add(newItem);
        notifyListeners();
        DBHelper.insert('history', {'id': newItem.id, 'dbValue': newItem.dbValue, 'dateTime': newItem.dateTime.toString(), 'description': newItem.description});
        print("Item added");
      } catch (error) {
        print(error);
        throw (error);
      }
    }

    updateItem(String id, String dbValue, DateTime dateTime, String description) {
      try {
        final newItem = History(id: id, dbValue: dbValue, dateTime: dateTime, description: description);
        _historyItems.add(newItem);
        notifyListeners();
        DBHelper.update('history', id, {'id': newItem.id, 'dbValue': newItem.dbValue, 'dateTime': newItem.dateTime.toString(), 'description': newItem.description});
        print("Item updated");
      } catch (error) {
        print(error);
        throw (error);
      }
    }

    Future<void> fetchAndSetHistory() async {
      final dataList = await DBHelper.getData('history');
      _historyItems = dataList.map((item) => History(id: item['id'], dbValue: item['dbValue'], dateTime: DateTime.parse(item['dateTime']), description: item['description'])).toList();
      notifyListeners();
    }
}
