import 'package:Straznik/providers/history/historyList.dart';
import 'package:Straznik/widgets/history_item.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:provider/provider.dart';

class AlarmDetailsScreen extends StatefulWidget {
  static const routeName = '/detail';
  String payload;
  HistoryItem item;

  AlarmDetailsScreen({@required this.payload, this.item});

  @override
  _AlarmDetailsScreenState createState() => _AlarmDetailsScreenState();
}

class _AlarmDetailsScreenState extends State<AlarmDetailsScreen> {
  TextEditingController descriptionController = TextEditingController();

  Future<void> refreshHistory(BuildContext context) async {
    await Provider.of<HistoryList>(context, listen: false).fetchAndSetHistory();
  }

  var focusNode = FocusNode();

  void createSnackBar(String message, Color color) async {
    final snackBar = new SnackBar(
        backgroundColor: color,
        elevation: 6.0,
        behavior: SnackBarBehavior.floating,
        content: Text(
          message,
          style: TextStyle(
            color: Theme.of(context).primaryColor,
          ),
        ));

    // Find the Scaffold in the Widget tree and use it to show a SnackBar!
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  @override
  Widget build(BuildContext context) {
    final historyData = Provider.of<HistoryList>(context, listen: false);
    final item = ModalRoute.of(context).settings.arguments as HistoryItem;

    void addDescription() {
      historyData.updateItem(
          item.id, item.dbValue, item.dateTime, descriptionController.text);
      createSnackBar("Opis dodany", Theme.of(context).accentColor);
    }

    final levelIndicator = Container(
      child: Container(
        child: LinearProgressIndicator(
            backgroundColor: Theme.of(context).buttonColor,
            value: 5,
            valueColor: AlwaysStoppedAnimation(Theme.of(context).errorColor)),
      ),
    );

    final topContentText = Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.end,
      children: <Widget>[
        Icon(
          Icons.wifi_tethering,
          color: Theme.of(context).accentColor,
          size: 40.0,
        ),
        Container(
          child: new Divider(color: Theme.of(context).accentColor),
        ),
        Padding(
          padding: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 0.0),
          child: Text(
            "${item.dbValue} dB",
            style:
                TextStyle(color: Theme.of(context).accentColor, fontSize: 35.0),
          ),
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            Expanded(
                flex: 6,
                child: Padding(
                    padding: EdgeInsets.only(left: 0.0, bottom: 8.0),
                    child: Text(
                      DateFormat('dd-MM-yyyy, HH:mm').format(item.dateTime),
                      style: TextStyle(
                          color: Theme.of(context).accentColor, fontSize: 15.0),
                    ))),
          ],
        ),
      ],
    );

    final topContent = Stack(
      children: <Widget>[
        Container(
          padding: EdgeInsets.only(left: 10.0),
          height: MediaQuery.of(context).size.height * 0.5,
          // decoration: new BoxDecoration(
          //   image: new DecorationImage(
          //     image: new AssetImage("drive-steering-wheel.jpg"),
          //     fit: BoxFit.cover,
          //   ),
          // )
        ),

        Container(
          height: MediaQuery.of(context).size.height * 0.5,
          padding: EdgeInsets.all(40.0),
          width: MediaQuery.of(context).size.width,
          decoration: BoxDecoration(color: Theme.of(context).primaryColor),
          child: Align(
            alignment: FractionalOffset.bottomCenter,
            child: Padding(
                padding: EdgeInsets.only(bottom: 10.0),
                child: topContentText //Your widget here,
                ),
          ),
        ),

        Positioned(
          left: 8.0,
          top: 60.0,
          child: InkWell(
            onTap: () {
              refreshHistory(context);
              Navigator.of(context).pop();
            },
            child: Icon(Icons.arrow_back, color: Theme.of(context).accentColor),
          ),
        )
      ],
    );

    final bottomContentText = TextField(
      keyboardType: TextInputType.multiline,
      maxLines: null,
      controller: descriptionController,
      scrollPadding: EdgeInsets.all(80.0),
      decoration: InputDecoration(
        hintText: (item.description == null || item.description == "")
            ? 'Dodaj opis alarmu'
            : item.description,
        contentPadding: EdgeInsets.all(30),
        filled: true,
        fillColor: Colors.white,
        border: OutlineInputBorder(),
        labelText: 'Opis alarmu',
        labelStyle: TextStyle(color: Theme.of(context).accentColor),
        floatingLabelBehavior: FloatingLabelBehavior.always,
      ),
    );

    final saveButton = Container(
      padding: EdgeInsets.symmetric(vertical: 16.0),
      width: MediaQuery.of(context).size.width,
      child: RaisedButton(
        onPressed: () => {addDescription()},
        color: Theme.of(context).accentColor,
        child: Text("ZAPISZ", style: TextStyle(color: Colors.white)),
      ),
    );

    final bottomContent = Container(
      // height: MediaQuery.of(context).size.height,
      width: MediaQuery.of(context).size.width,
      // color: Theme.of(context).primaryColor,
      padding: EdgeInsets.all(40.0),
      child: Center(
        child: Column(
          children: <Widget>[Semantics(
              label: 'Dodaj opis alarmu',
              child: bottomContentText
          ), saveButton],
        ),
      ),
    );

    return Scaffold(
      body: WillPopScope(
        onWillPop: () {
          refreshHistory(context);
          Navigator.of(context).pop();
        },
        child: GestureDetector(
          onTap: () {
            FocusScope.of(context).requestFocus(new FocusNode());
          },
          child: SingleChildScrollView(
            child: Center(
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: <Widget>[topContent, bottomContent],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
