import 'package:Straznik/providers/history/historyList.dart';
import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/widgets/history_item.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

enum FilterOptions { Torch, Sound, Vibration }

class HistoryScreen extends StatefulWidget {
  static const routeName = '/history';
  refresh() => createState().refreshHistory;

  @override
  _HistoryScreenState createState() => _HistoryScreenState();
}

class _HistoryScreenState extends State<HistoryScreen> {

  Future<void> refreshHistory(BuildContext context) async {
    await Provider.of<HistoryList>(context, listen: false).fetchAndSetHistory();
  }

  void disableStartedParam(){
    final alarmDetectionEnabled = Provider.of<NotificationProvider>(context, listen: false);
    WidgetsBinding.instance.addPostFrameCallback((_){
      alarmDetectionEnabled.setAlarmStatus(false);
    });
  }

  @override
  void initState() {
    super.initState();
    disableStartedParam();
  }

  @override
  Widget build(BuildContext context) {
    // final historyData = Provider.of<HistoryList>(context);
    return RefreshIndicator(
      backgroundColor: Theme.of(context).accentColor,
      color: Theme.of(context).primaryColor,
      onRefresh: () => refreshHistory(context),
      child: Semantics(
        label: "Historia wykrytych dźwięków",
        child: Column(
          children: [
            Container(
              child: Padding(
                padding: EdgeInsets.fromLTRB(10, 15, 0, 15),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Text(
                      "Wykryte alarmy",
                      textAlign: TextAlign.start,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(fontWeight: FontWeight.bold, fontSize: 27),
                    ),
                  ],
                ),
              ),
            ),
            Expanded(
              child: FutureBuilder(
                future: Provider.of<HistoryList>(context, listen: false)
                    .fetchAndSetHistory(),
                builder: (ctx, snapshot) => snapshot.connectionState ==
                        ConnectionState.waiting
                    ? Center(
                        child: CircularProgressIndicator(),
                      )
                    : Consumer<HistoryList>(
                      child: Align(
                        alignment: Alignment(0.2, -0.3),
                        child: Container(
                          width: MediaQuery.of(context).size.width * 0.9,
                          child: Column(
                            mainAxisSize: MainAxisSize.min,
                            crossAxisAlignment: CrossAxisAlignment.center,
                            children: <Widget>[
                              Image.asset(
                                'assets/nohistoryitem.png',
                                fit: BoxFit.cover,
                                height: 120.0,
                              ),
                              const Text(
                                'Brak alarmów',
                                style: TextStyle(
                                    fontSize: 19, fontWeight: FontWeight.bold),
                                textAlign: TextAlign.center,
                              ),
                            ],
                          ),
                          // Center(
                          //   child: ,
                          // ),
                        ),
                      ),
                      builder: (ctx, historyData, ch) =>
                          historyData.historyItems.length <= 0
                              ? ch
                              : ListView.builder(
                                  scrollDirection: Axis.vertical,
                                  shrinkWrap: true,
                                  itemCount: historyData.historyItems.length,
                                  itemBuilder: (ctx, i) => HistoryItem(
                                    historyData.historyItems[i].id,
                                    historyData.historyItems[i].dbValue,
                                    historyData.historyItems[i].dateTime,
                                    historyData.historyItems[i].description,
                                  ),
                                ),
                    ),
              ),
            ),
            // ),
          ],
        ),
      ),
    );
  }
}
