import 'dart:io' show Platform;

import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/screens/settings/settings_screen.dart';
import 'package:Straznik/screens/straznik/straznik_screen.dart';
import 'package:Straznik/widgets/tutorial_widgets/InfoDialogBox.dart';
import 'package:Straznik/widgets/tutorial_widgets/dialogs.dart';
import 'package:double_back_to_close_app/double_back_to_close_app.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_boom_menu/flutter_boom_menu.dart';
import 'package:provider/provider.dart';

import 'history/history_screen.dart';

class MainScreen extends StatefulWidget {
  MainScreen({Key key}) : super(key: key);
  static const routeName = '/main';
  final GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  _MainScreenState createState() => _MainScreenState();
}

class _MainScreenState extends State<MainScreen> {
  int _selectedIndex = 0;
  ScrollController scrollController;
  bool scrollVisible = true;

  static List<Widget> _widgetOptions = <Widget>[
    StraznikScreen(),
    SettingsScreen(),
    HistoryScreen()
  ];

  static List<Dialogs> _infos = <Dialogs>[
    Dialogs("Strażnik", "Korzystając z przycisku START/STOP możesz włączyć/wyłączyć funkcję wykrywania alarmu."),
    Dialogs("Ustawienia", "Tutaj ustawisz w jaki sposób aplikacja powiadomi Cię o wykrytym alarmie."),
    Dialogs("Historia", "Tutaj masz podgląd wszystkich wykrytych przez aplikację alarmów. Możesz je usuwać, przeciągając wybrany element w lewo lub dodać opis, klikając w niego.")
  ];

  void _onItemTapped(int index) {
    setState(() {
      _selectedIndex = index;
    });
  }

  @override
  void initState() {
    super.initState();

    scrollController = ScrollController()
      ..addListener(() {
        setDialVisible(scrollController.position.userScrollDirection ==
            ScrollDirection.forward);
      });
  }

  void setDialVisible(bool value) {
    setState(() {
      scrollVisible = value;
    });
  }

  showInfoDialog(title, description) {
    showDialog(
        context: context,
        builder: (BuildContext context) {
          return InfoDialogBox(
            title: title,
            descriptions: description,
            text: "Okej",
          );
        });
  }

  @override
  Widget build(BuildContext context) {
    final alarmDetectionEnabled =
        Provider.of<NotificationProvider>(context, listen: false);

    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        centerTitle: true,
        title: _infos[_selectedIndex],
        backgroundColor: Theme.of(context).primaryColor,
        elevation: 0,
      ),
      body: DoubleBackToCloseApp(
        snackBar: SnackBar(
          elevation: 6.0,
          behavior: SnackBarBehavior.floating,
          backgroundColor: Theme.of(context).accentColor,
          content: Text(
            alarmDetectionEnabled.alarmOn
                ? 'Po wyjściu z aplikacji ochrona będzie wyłączona'
                : 'Naciśnij jeszcze raz, aby wyjść z aplikacji',
            style: TextStyle(
                color: Theme.of(context).primaryColor,
                fontWeight: FontWeight.bold),
          ),
        ),
        child: Center(
          child: _widgetOptions.elementAt(_selectedIndex),
        ),
      ),
      bottomNavigationBar: BottomNavigationBar(
        backgroundColor: Theme.of(context).accentColor,
        items: const <BottomNavigationBarItem>[
          BottomNavigationBarItem(
            icon: Icon(Icons.home),
            label: 'Strażnik',
          ),
          BottomNavigationBarItem(
            icon: Icon(Icons.settings),
            label: 'Ustawienia',
          ),
          BottomNavigationBarItem(
            icon: Icon(Icons.history),
            label: 'Historia',
          ),
        ],
        currentIndex: _selectedIndex,
        unselectedItemColor: Theme.of(context).primaryColor,
        selectedItemColor: Theme.of(context).buttonColor,
        onTap: _onItemTapped,
      ),
      // floatingActionButton:
      //   Visibility(
      //     child: buildBoomMenu(),
      //     visible: _selectedIndex == 2 ? true : false, // set it to false
      //   ),
    );
  }
}
// FloatingActionButton(
// onPressed: () {
// // Add your onPressed code here!
// },
// child: const Icon(
// Icons.search,
// color: Color.fromRGBO(255, 208, 0, 1),
// ),
// backgroundColor: Theme.of(context).accentColor,
// ),
