import 'dart:io' show Platform;

import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/screens/settings/phone/phone_timer_settings.dart';
import 'package:Straznik/widgets/tutorial_widgets/dialogs.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:settings_ui/settings_ui.dart';

class PhoneSettingsScreen extends StatefulWidget {
  static const routeName = '/phonesettings';

  @override
  _PhoneSettingsScreenState createState() => _PhoneSettingsScreenState();
}

class _PhoneSettingsScreenState extends State<PhoneSettingsScreen> {
  bool vibration = false;
  String valueText;
  String codeDialog;
  bool valueSwitch;

  final _formKey = GlobalKey<FormState>();

  Future<void> showPhoneNumberDialog(BuildContext context) async {
    final phoneNumber = Provider.of<Phone>(context, listen: false);
    return await showDialog(
      context: context,
      builder: (context) {
        TextEditingController textEditingController = TextEditingController();
        return AlertDialog(
          content: Form(
              key: _formKey,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Semantics(
                    label: "Wpisz numer telefonu. Obecnie obsługiwane są tylko polskie numery.",
                    child: TextFormField(
                      controller: textEditingController,
                      keyboardType: TextInputType.phone,
                      maxLines: 1,
                      autofocus: true,
                      validator: (value) {
                        return value.isEmpty || value.length != 9
                            ? "Niepoprawny numer"
                            : null;
                      },
                      decoration:
                          InputDecoration(
                            hintText: "Numer telefonu",
                            helperText: "Opłata za połączenie lub SMS zgodna z taryfą operatora",
                            helperMaxLines: 2,
                            prefixText: "+48 "
                          ),
                      onSaved: (value) {
                        setState(() {
                          valueText = value;
                        });
                      },
                    ),
                  ),
                ],
              )),
          actions: <Widget>[
            TextButton(
              child: Text('ANULUJ', style: TextStyle(color: Theme.of(context).accentColor),),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            TextButton(
              child: Text('OK', style: TextStyle(color: Theme.of(context).accentColor),),
              onPressed: () {
                setState(() {
                  if (_formKey.currentState.validate()) {
                    phoneNumber.setPhoneNumber(textEditingController.text);
                    Navigator.of(context).pop();
                  }
                });
              },
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    final phone = Provider.of<Phone>(context, listen: true);
    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        centerTitle: true,
        title: Dialogs("Ustawienia połączeń", "Tutaj możesz włączyć połączenia alarmowe. Są to połączenia wykonywane przez aplikację na wskazany numer po ustalonym czasie od wykrycia alarmu."),
        backgroundColor: Theme.of(context).primaryColor,
        elevation: 0,
      ),
      body: Semantics(
        label: Platform.isAndroid ? 'Ustawienia połączeń' : 'Ustawienia wiadomości',
        child: SettingsList(
          backgroundColor: Theme.of(context).primaryColor,
          sections: [
            SettingsSection(
              title: Platform.isAndroid ? 'Połączenia alarmowe' : 'Wiadomości alarmowe',
              titleTextStyle: TextStyle(color: Theme
                  .of(context)
                  .accentColor, fontWeight: FontWeight.bold, fontSize: 27),
              titlePadding: EdgeInsets.fromLTRB(10,15,0,15),
              tiles: [
                SettingsTile.switchTile(
                  title: Platform.isAndroid ? 'Zadzwoń' : 'Wyślij wiadomość',
                  titleMaxLines: 3,
                  subtitle: 'pod wskazany numer',
                  subtitleMaxLines: 3,
                  semanticsHint: Platform.isAndroid ? "Zaznacz aby po wykryciu alarmu telefon zadzwonił pod wskazany numer telefonu po wybranym czasie" : "Zaznacz aby po wykryciu alarmu telefon wysłał wiadomość SMS pod wskazany numer telefonu po wybranym czasie",
                  semanticsValue: "$valueSwitch",
                  leading: Icon(Icons.phone),
                  switchValue: phone.status,
                  onToggle: (bool value) async {
                    print(value);
                    valueSwitch = value;
                    if(value == true && (phone.phoneNumber == null || phone.phoneNumber == "")){
                      await showPhoneNumberDialog(context);
                      if(phone.phoneNumber == null || phone.phoneNumber == ""){
                        value = false;
                      }else{
                        setState(() {
                          phone.setStatus(value);
                        });
                      }
                    } else{
                      setState(() {
                        phone.setStatus(value);
                      });
                    }
                  },
                ),
                SettingsTile(
                  visibility: phone.status ? true : false,
                  title: 'Numer telefonu:',
                  titleMaxLines: 3,
                  semanticsHint: Platform.isAndroid ? "Kliknij dwukrotnie aby wprowadzić numer telefonu do połączeń alarmowych" : "Kliknij dwukrotnie aby wprowadzić numer telefonu do wiadomości alarmowych",
                  subtitle: phone.phoneNumber == null || phone.phoneNumber == ""
                      ? "Brak numeru"
                      : "+48 "+phone.phoneNumber,
                  leading: Icon(Icons.phone_in_talk),
                  onPressed: (BuildContext context) async {
                    await showPhoneNumberDialog(context);
                  },
                ),
                SettingsTile(
                  visibility: phone.status ? true : false,
                  title: Platform.isAndroid ? 'Połączenie po czasie:' : 'Wiadomość po czasie',
                  titleMaxLines: 3,
                  semanticsHint: Platform.isAndroid ? "Kliknij dwukrotnie aby zmienić czas po którym nastąpi połączenie alarmowe" : "Kliknij dwukrotnie aby zmienić czas po którym nastąpi wysłanie wiadomości alarmowej",
                  subtitle: phone.awaitTime.toString() + " sekund",
                  leading: Icon(Icons.timelapse),
                  onPressed: (BuildContext context) {
                    Navigator.of(context)
                        .pushNamed(PhoneTimerSettingsScreen.routeName);
                  },
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
