import 'dart:io' show Platform;

import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/widgets/tutorial_widgets/dialogs.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:settings_ui/settings_ui.dart';

class PhoneTimerSettingsScreen extends StatefulWidget {
  static const routeName = '/phonetimersettings';

  @override
  _PhoneTimerSettingsScreenState createState() => _PhoneTimerSettingsScreenState();
}

class _PhoneTimerSettingsScreenState extends State<PhoneTimerSettingsScreen> {
  int timeIndex;

  @override
  void initState() {
    final phone = Provider.of<Phone>(context, listen: false);
    timeIndex = phone.awaitTime == null ? 2 : phone.awaitTimeValues.indexWhere((element) => element==phone.awaitTime);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        centerTitle: true,
        title: Dialogs("Ustawienia czasu","Tutaj możesz ustawić czas od wykrycia alarmu, po którym nastąpi połączenie alarmowe, jeżeli nie zareagujesz na powiadomienia STRAŻNIKA."),
        backgroundColor: Theme.of(context).primaryColor,
        elevation: 0,
      ),
      body: Semantics(
        label: Platform.isAndroid ? "Ustawienia czasu po którym nastąpi połączenie pod wskazany numer telefonu": "Ustawienia czasu po którym zostanie wysłana wiadomość na wskazany numer telefonu",
        hint: "Wybierz czas z listy",
        child: SettingsList(
          sections: [
            SettingsSection(
                title: Platform.isAndroid ? 'Połączenie po czasie:' : 'Wiadomość po czasie:',
                maxLines: 3,
                // subtitle: Text('Połączenie telefoniczne zostanie aktywowane po wskazanym czasie od momentu uruchomienia alarmu'),
                // subtitlePadding: EdgeInsets.fromLTRB(10,20,0,15),
                titleTextStyle: TextStyle(color: Theme
                    .of(context)
                    .accentColor, fontWeight: FontWeight.bold, fontSize: 24),
                titlePadding: EdgeInsets.fromLTRB(10,15,0,15),
                tiles: [
              SettingsTile(
                title: "5 sekund",
                semanticsValue: "5 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 5 sekund",
                trailing: trailingWidget(0),
                onTap: () {
                  changeTime(0);
                },
              ),
              SettingsTile(
                title: "10 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 10 sekund",
                trailing: trailingWidget(1),
                onTap: () {
                  changeTime(1);
                },
              ),
              SettingsTile(
                title: "15 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 15 sekund",
                trailing: trailingWidget(2),
                onTap: () {
                  changeTime(2);
                },
              ),
              SettingsTile(
                title: "20 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 20 sekund",
                trailing: trailingWidget(3),
                onTap: () {
                  changeTime(3);
                },
              ),
              SettingsTile(
                title: "25 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 25 sekund",
                trailing: trailingWidget(4),
                onTap: () {
                  changeTime(4);
                },
              ),
              SettingsTile(
                title: "30 sekund",
                semanticsHint: "Kliknij dwukrotnie aby wybrać 30 sekund",
                trailing: trailingWidget(5),
                onTap: () {
                  changeTime(5);
                },
              ),
            ]),
          ],
        ),
      ),
    );
  }

  Widget trailingWidget(int index) {
    return (timeIndex == index)
        ? Icon(Icons.check, color: Theme.of(context).accentColor)
        : Icon(null);
  }

  void changeTime(int index) {
    final phone = Provider.of<Phone>(context, listen: false);
    setState(() {
      timeIndex = index;
      phone.setAwaitTime(index);
    });
  }
}
