import 'dart:io' show Platform;

import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/providers/warn_providers/torch_provider.dart';
import 'package:Straznik/providers/warn_providers/vibration_provider.dart';
import 'package:Straznik/screens/settings/phone/phone_settings_screen.dart';
import 'package:Straznik/screens/settings/smartband/smartband_settings_screen.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:settings_ui/settings_ui.dart';

class SettingsScreen extends StatefulWidget {
  static const routeName = '/settings';

  @override
  _SettingsScreenState createState() => _SettingsScreenState();
}

class _SettingsScreenState extends State<SettingsScreen> {
  bool vibration = false;
  String valueText;
  String codeDialog;

  void disableStartedParam() {
    final alarmDetectionEnabled =
        Provider.of<NotificationProvider>(context, listen: false);
    WidgetsBinding.instance.addPostFrameCallback((_) {
      alarmDetectionEnabled.setAlarmStatus(false);
    });
  }

  @override
  void initState() {
    super.initState();
    disableStartedParam();
  }

  final _formKey = GlobalKey<FormState>();

  Future<void> showPhoneNumberDialog(BuildContext context) async {
    final phoneNumber = Provider.of<Phone>(context, listen: false);
    return await showDialog(
      context: context,
      builder: (context) {
        TextEditingController textEditingController = TextEditingController();
        return AlertDialog(
          content: Form(
              key: _formKey,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  TextFormField(
                    controller: textEditingController,
                    keyboardType: TextInputType.phone,
                    validator: (value) {
                      return value.isEmpty || value.length != 9
                          ? "Niepoprawny numer"
                          : null;
                    },
                    decoration:
                        InputDecoration(hintText: "Wpisz numer telefonu"),
                    onSaved: (value) {
                      setState(() {
                        valueText = value;
                      });
                    },
                  ),
                ],
              )),
          actions: <Widget>[
            TextButton(
              child: Text('ANULUJ'),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            TextButton(
              child: Text('OK'),
              onPressed: () {
                setState(() {
                  if (_formKey.currentState.validate()) {
                    phoneNumber.setPhoneNumber(textEditingController.text);
                    Navigator.of(context).pop();
                  }
                });
              },
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    final torch = Provider.of<TorchProvider>(context, listen: false);
    final vibration = Provider.of<VibrationProvider>(context, listen: false);

    return Stack(
      children: [
        Positioned(
          child: Semantics(
            label: "Ustawienia funkcji ostrzegania",
            child: SettingsList(
              backgroundColor: Theme.of(context).primaryColor,
              sections: [
                SettingsSection(
                  title: 'Ostrzeganie',
                  titleTextStyle: TextStyle(
                      color: Theme.of(context).accentColor,
                      fontWeight: FontWeight.bold,
                      fontSize: 27),
                  titlePadding: EdgeInsets.fromLTRB(10, 15, 0, 15),
                  tiles: [
                    SettingsTile.switchTile(
                      title: 'Użyj wibracji w telefonie',
                      titleMaxLines: 3,
                      semanticsHint:
                          "Zaznacz aby po wykryciu alarmu aktywowały się wibracje w telefonie",
                      leading: Icon(Icons.vibration),
                      switchValue: vibration.status,
                      onToggle: (bool value) {
                        setState(() {
                          vibration.setStatus(value);
                        });
                      },
                    ),
                    SettingsTile.switchTile(
                      title: 'Użyj latarki',
                      titleMaxLines: 3,
                      semanticsHint:
                          "Zaznacz aby po wykryciu alarmu włączyła się latarka w telefonie",
                      leading: Icon(Icons.lightbulb_outline),
                      switchValue: torch.status,
                      onToggle: (bool value) {
                        setState(() {
                          torch.setStatus(value);
                        });
                      },
                    ),
                    // SettingsTile.switchTile(
                    //   title: 'Użyj sygnału dźwiękowego',
                    //   leading: Icon(Icons.surround_sound),
                    //   switchValue: sound.status,
                    //   onToggle: (bool value) {
                    //     setState(() {
                    //       sound.setStatus(value);
                    //     });
                    //   },
                    // ),
                    SettingsTile(
                      visibility: Platform.isAndroid,
                      title: Platform.isAndroid ? 'Połączenia alarmowe' : 'Wiadomość alarmowa',
                      titleMaxLines: 3,
                      semanticsHint:
                      Platform.isAndroid ? "Kliknij dwukrotnie aby przejść do ustawień połączeń alarmowych" : "Kliknij dwukrotnie aby przejść do ustawień wiadomości alarmowych",
                      leading: Icon(Platform.isAndroid ? Icons.phone : Icons.message),
                      onPressed: (context) {
                        Navigator.of(context)
                            .pushNamed(PhoneSettingsScreen.routeName);
                      },
                    ),
                    SettingsTile(
                      title: 'Opaska wibrująca',
                      titleMaxLines: 3,
                      semanticsHint:
                      "Kliknij dwukrotnie aby przejść do ustawień czasu po którym uruchomią się wibracje w opasce",
                      leading: Icon(Icons.watch),
                      onPressed: (context) {
                        Navigator.of(context)
                            .pushNamed(SmartbandSettingsScreen.routeName);
                      },
                    ),
                  ],
                ),
                CustomSection(
                  child: Column(
                    children: [
                      Padding(
                        padding: const EdgeInsets.only(top: 40, bottom: 90),
                        // child: Image.asset(
                        //   'assets/settings.png',
                        //   height: 50,
                        //   width: 50,
                        //   color: Color(0xFF777777),
                        // ),
                      ),
                      Text(
                        'Wersja: 2.0.1',
                        style: TextStyle(color: Theme.of(context).disabledColor),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ],
    );
  }
}
