import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/widgets/tutorial_widgets/dialogs.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:settings_ui/settings_ui.dart';

class SmartbandTimerScreen extends StatefulWidget {
  static const routeName = '/smartbandtimer';

  @override
  _SmartbandTimerScreen createState() => _SmartbandTimerScreen();
}

class _SmartbandTimerScreen extends State<SmartbandTimerScreen> {
  int timeIndex;

  @override
  void initState() {
    final notification =
        Provider.of<NotificationProvider>(context, listen: false);
    timeIndex = notification.vibrationTime == null
        ? 4
        : notification.awaitTimeValues
            .indexWhere((element) => element == notification.vibrationTime);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Theme.of(context).primaryColor,
      appBar: AppBar(
        centerTitle: true,
        title: Dialogs("Ustawienia czasu",
            "Tutaj ustawisz czas po którym w Twojej opasce aktywują się kolejne wibracje. Na przykład: jeżeli wibracje w Twojej opasce trwają 2 sekundy, wybierz z listy 3 sekundy. Jeżeli trwają 10 sekund, wybierz 13 sekund."),
        backgroundColor: Theme.of(context).primaryColor,
        elevation: 0,
      ),
      body: Semantics(
        label: "Ustawienia czasu po którym wystąpi wibracja w opasce",
        hint: "Wybierz czas z listy",
        child: SettingsList(
          sections: [
            SettingsSection(
                title: 'Kolejne wibracje w opasce po czasie:',
                maxLines: 3,
                // subtitle: Text('Połączenie telefoniczne zostanie aktywowane po wskazanym czasie od momentu uruchomienia alarmu'),
                // subtitlePadding: EdgeInsets.fromLTRB(10,20,0,15),
                titleTextStyle: TextStyle(
                    color: Theme.of(context).accentColor,
                    fontWeight: FontWeight.bold,
                    fontSize: 24),
                titlePadding: EdgeInsets.fromLTRB(10, 15, 0, 15),
                tiles: [
                  SettingsTile(
                    title: "3 sekundy",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 3 sekund",
                    trailing: trailingWidget(0),
                    onTap: () {
                      changeTime(0);
                    },
                  ),
                  SettingsTile(
                    title: "5 sekund",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 5 sekund",
                    trailing: trailingWidget(1),
                    onTap: () {
                      changeTime(1);
                    },
                  ),
                  SettingsTile(
                    title: "8 sekund",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 8 sekund",
                    trailing: trailingWidget(2),
                    onTap: () {
                      changeTime(2);
                    },
                  ),
                  SettingsTile(
                    title: "10 sekund",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 10 sekund",
                    trailing: trailingWidget(3),
                    onTap: () {
                      changeTime(3);
                    },
                  ),
                  SettingsTile(
                    title: "13 sekund  (zalecane dla Mi Band)",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 13 sekund",
                    trailing: trailingWidget(4),
                    onTap: () {
                      changeTime(4);
                    },
                  ),
                  SettingsTile(
                    title: "15 sekund",
                    semanticsHint: "Kliknij dwukrotnie aby wybrać 15 sekund",
                    trailing: trailingWidget(5),
                    onTap: () {
                      changeTime(5);
                    },
                  ),
                ]),
          ],
        ),
      ),
    );
  }

  Widget trailingWidget(int index) {
    return (timeIndex == index)
        ? Icon(Icons.check, color: Theme.of(context).accentColor)
        : Icon(null);
  }

  void changeTime(int index) {
    final notification =
        Provider.of<NotificationProvider>(context, listen: false);
    setState(() {
      timeIndex = index;
      notification.setAwaitTime(index);
    });
  }
}
