import 'dart:io' show Platform;

import 'package:Straznik/providers/history/historyList.dart';
import 'package:Straznik/providers/warn_providers/notification_provider.dart';
import 'package:Straznik/providers/warn_providers/phone_provider.dart';
import 'package:Straznik/providers/warn_providers/torch_provider.dart';
import 'package:Straznik/providers/warn_providers/vibration_provider.dart';
import 'package:Straznik/screens/main_screen.dart';
import 'package:Straznik/services/permission_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:flutter_sms/flutter_sms.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:noise_meter/noise_meter.dart';
import 'package:provider/provider.dart';
import 'dart:async';
import 'package:torch_compat/torch_compat.dart';
import 'package:uuid/uuid.dart';

class StraznikScreen extends StatefulWidget {
  static const routeName = '/straznik';

  @override
  _StraznikScreenState createState() => _StraznikScreenState();
}

class _StraznikScreenState extends State<StraznikScreen> {
  Color buttonColor;
  bool _isRecording = false;
  bool _isLoading = true;
  bool started = false;
  bool gettingData = false;

  FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin =
      FlutterLocalNotificationsPlugin();
  var uuid = Uuid();

  StreamSubscription<NoiseReading> _noiseSubscription;

  NoiseMeter _noiseMeter;

  Timer logTimer;

  Timer startTimer;

  var logMeter = 0;

  bool torchStatus = false;

  int soundDB = 0;

  fetchAndSetProvidersData() {
    final torch = Provider.of<TorchProvider>(context, listen: false);
    final vibration = Provider.of<VibrationProvider>(context, listen: false);
    final phone = Provider.of<Phone>(context, listen: false);
    final notificationProvider =
        Provider.of<NotificationProvider>(context, listen: false);

    setState(() {
      phone.fetchAndSetData();
      torch.fetchAndSetData();
      vibration.fetchAndSetData();
      notificationProvider.fetchAndSetData();
      _isLoading = false;
    });
  }

  void _sendSMS(List<String> recipents) async {
    try {
      String result = await sendSMS(
          message: "Wiadomość wygenerowana przez aplikację STRAŻNIK do wykrywania alarmów. U nadawcy tej wiadomości wykryto regularny dźwięk o wysokości "+ soundDB.toString() + " decybeli.",
          recipients: recipents);
      print(result);
    } catch (error) {
      print(error);
    }
  }

  @override
  Future<void> initState() {
    super.initState();
    PermissionsService.requestPermissions();
    _requestPermissions();
    _noiseMeter = new NoiseMeter(onError);

    fetchAndSetProvidersData();

    const AndroidInitializationSettings initializationSettingsAndroid =
        AndroidInitializationSettings('@mipmap/ic_launcher');
    final IOSInitializationSettings initializationSettingsIOS =
        IOSInitializationSettings();
    final MacOSInitializationSettings initializationSettingsMacOS =
        MacOSInitializationSettings();
    final InitializationSettings initializationSettings =
        InitializationSettings(
            android: initializationSettingsAndroid,
            iOS: initializationSettingsIOS,
            macOS: initializationSettingsMacOS);
    flutterLocalNotificationsPlugin.initialize(initializationSettings,
        onSelectNotification: onSelectNotification);
  }

  void _requestPermissions() {
    flutterLocalNotificationsPlugin
        .resolvePlatformSpecificImplementation<
            IOSFlutterLocalNotificationsPlugin>()
        ?.requestPermissions(
          alert: true,
          badge: true,
          sound: true,
        );
    flutterLocalNotificationsPlugin
        .resolvePlatformSpecificImplementation<
            MacOSFlutterLocalNotificationsPlugin>()
        ?.requestPermissions(
          alert: true,
          badge: true,
          sound: true,
        );
  }

  Future onSelectNotification(String payload) {
    Navigator.push(
        context, MaterialPageRoute(builder: (context) => MainScreen()));
  }

  showNotification(String title, String message, String payload) async {
    var android = AndroidNotificationDetails('id', 'channel ', 'description',
        priority: Priority.high, importance: Importance.max);
    var iOS = IOSNotificationDetails();
    var platform = new NotificationDetails(android: android, iOS: iOS);
    await flutterLocalNotificationsPlugin.show(0, title, message, platform,
        payload: payload);
  }

  Future cancelAndShowNotification(
      String title, String message, String payload) async {
    await flutterLocalNotificationsPlugin.cancelAll();
    showNotification(title, message, payload);
  }

  void alarmDetected(String dbValue) {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    final historyData = Provider.of<HistoryList>(context, listen: false);
    final torch = Provider.of<TorchProvider>(context, listen: false);
    final vibration = Provider.of<VibrationProvider>(context, listen: false);
    final phone = Provider.of<Phone>(context, listen: false);
    final notificationProvider =
        Provider.of<NotificationProvider>(context, listen: false);

    torchStatus = torch.status;
    historyData.addItem(uuid.v1(), dbValue, DateTime.now(), '');
    stop();
    vibration.status ? vibration.startVibrations() : 0;
    cancelAndShowNotification('Wykryto dźwięk: '+ soundDB.toString()+' dB',
        'Sprawdź czy jesteś bezpieczny!', 'Szczegóły alarmu');
    torch.status ? TorchCompat.turnOn() : 0;
    Timer timer = Timer(Duration(milliseconds: phone.awaitTime * 1000), () {
      List<String> recipents = [phone.phoneNumber];
      phone.status ? (Platform.isAndroid ? phone.callNumber(phone.phoneNumber) : 0) : 0;
    });
    Timer push = Timer.periodic(
        Duration(milliseconds: notificationProvider.vibrationTime * 1000),
        (timer) {
      vibration.status ? vibration.startVibrations() : 0;
      notificationProvider.watchStatus ? cancelAndShowNotification('Wykryto dźwięk: '+ soundDB.toString()+' dB',
          'Sprawdź czy jesteś bezpieczny!', 'Szczegóły alarmu') : 0;
    });
    showDialog(
      barrierDismissible: false,
      context: context,
      builder: (ctx) => Semantics(
        // label: "Uruchomił się alarm! Sprawdź czy jesteś bezpieczny!",
        // hint: "Naciśnij okej aby wyłączyć alarm",
        child: AlertDialog(
          title: Text('Wykryto dźwięk: '+ soundDB.toString()+' dB'),
          content: Text('Sprawdź czy jesteś bezpieczny!'),
          actions: <Widget>[
            FlatButton(
              child: Text(
                'Stop',
                style: TextStyle(color: Theme.of(context).accentColor),
              ),
              onPressed: () {
                Navigator.of(ctx).pop();
                TorchCompat.turnOff();
                vibration.stopVibrations();
              },
            ),
          ],
        ),
      ),
    ).then((value) {
      // dispose the timer in case something else has triggered the dismiss.
      timer?.cancel();
      push?.cancel();
      timer = null;
      push = null;
    });
  }

  void resetLogs() {
    logTimer == null ? 0 : logTimer.cancel();
    logTimer = Timer(Duration(milliseconds: 10000), () {
      logMeter = 0;
    });
  }

  Future start() async {
    started = true;
    final alarmDetectionEnabled =
        Provider.of<NotificationProvider>(context, listen: false);
    alarmDetectionEnabled.setAlarmStatus(true);
    startTimer == null ? 0 : startTimer.cancel();
    this.setState(() {
      if (!this._isRecording) {
        this._isRecording = true;
      }
    });
    createSnackBar('Ochrona włączona', Theme.of(context).buttonColor);
    startTimer = Timer(Duration(milliseconds: 5000), () {
      print("START!!!!!!");
      enableDetection();
    });
  }

  Future enableDetection() async {
    gettingData = true;
    try {
      _noiseSubscription = _noiseMeter.noiseStream.listen(onData);
    } catch (err) {
      print(err);
    }
  }

  void onData(NoiseReading noiseReading) {
    // print(noiseReading.toString());
    if (noiseReading.maxDecibel > 65) {
      resetLogs();
      logMeter++;
      print(logMeter);
      if (logMeter == 15) {
        logMeter = 0;
        soundDB = noiseReading.maxDecibel.round();
        alarmDetected(noiseReading.maxDecibel.round().toString());
      }
    }
  }

  void onError(PlatformException e) {
    print(e.toString());
    _isRecording = false;
  }

  Future stop() async {
    started = false;
    startTimer?.cancel();
    final alarmDetectionEnabled =
        Provider.of<NotificationProvider>(context, listen: false);
    alarmDetectionEnabled.setAlarmStatus(false);
    try {
      if (_noiseSubscription != null) {
        _noiseSubscription.cancel();
        _noiseSubscription = null;
      }
      this.setState(() {
        this._isRecording = false;
        createSnackBar('Ochrona wyłączona', Theme.of(context).errorColor);
      });
    } catch (err) {
      print('stopRecorder error: $err');
    }
  }

  @override
  Widget build(BuildContext context) {
    return _isLoading
        ? Center(
            child: CircularProgressIndicator(),
          )
        :
        // Column(
        //       children: [
        Container(
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                  shape: CircleBorder(),
                  primary: Theme.of(context).accentColor),
              child: Semantics(
                label: "Przycisk obsługi Strażnika",
                hint: _isRecording
                    ? "Kliknij dwukrotnie aby wyłączyć Strażnika"
                    : "Kliknij dwukrotnie aby włączyć Strażnika",
                child: ExcludeSemantics(
                  child: Container(
                    width: 200,
                    height: 200,
                    alignment: Alignment.center,
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      border: Border.all(
                        color: _isRecording
                            ? Theme.of(context).buttonColor
                            : Theme.of(context).errorColor,
                        width: 15,
                      ),
                    ),
                    child: Text(
                      _isRecording ? "STOP" : "START",
                      style: GoogleFonts.raleway(
                        textStyle: TextStyle(
                            fontSize: 30,
                            color: Theme.of(context).primaryColor,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ),
                ),
              ),
              onPressed: _isRecording
                  ? () => {
                        stop(),
                      }
                  : () => {
                        start(),
                      },
            ),
          );
    // Container(
    //   child: AlarmIndicator(),
    // )
    // ],
  }

  void createSnackBar(String message, Color color) async {
    setState(() {
      _isLoading = false;
    });
    final snackBar = new SnackBar(
        backgroundColor: color,
        elevation: 6.0,
        behavior: SnackBarBehavior.floating,
        content: Text(
          message,
          style: TextStyle(
            color: Theme.of(context).primaryColor,
          ),
        ));

    // Find the Scaffold in the Widget tree and use it to show a SnackBar!
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  void setStatus(bool status) {
    final alarmDetectionEnabled =
        Provider.of<NotificationProvider>(context, listen: false);
    alarmDetectionEnabled.setAlarmStatus(status);
    started = status;
  }


  @override
  void dispose() {
    started
        ? cancelAndShowNotification(
            "Uwaga!",
            'Funkcja wykrywania alarmów została wyłączona.',
            'Szczegóły alarmów')
        : 0;
    started ? startTimer?.cancel() : 0;
    started && torchStatus ? TorchCompat.turnOff() : 0;
    started && gettingData ? _noiseSubscription.cancel() : 0;
    super.dispose();
  }
}
