import 'dart:async';
import 'dart:io';

import 'package:Straznik/providers/history/historyList.dart';
import 'package:Straznik/screens/history/alarm_details_screen.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:provider/provider.dart';

class HistoryItem extends StatefulWidget {
  final String id;
  final String dbValue;
  final DateTime dateTime;
  final String description;

  HistoryItem(this.id, this.dbValue, this.dateTime, this.description);

  @override
  _HistoryItemState createState() => _HistoryItemState();
}

class _HistoryItemState extends State<HistoryItem> {
  // FutureOr onGoBack(dynamic value) {
  //   HistoryScreen().refresh();
  //   setState(() {});
  // }

  @override
  Widget build(BuildContext context) {
    // final scaffold = ScaffoldMessenger.of(context);
    return Dismissible(
      key: ValueKey(widget.id),
      background: Container(
        color: Theme.of(context).errorColor,
        child: Icon(
          Icons.delete,
          color: Theme.of(context).primaryColor,
          // size: 40,
        ),
        alignment: Alignment.centerRight,
        padding: EdgeInsets.only(right: 20),
        margin: EdgeInsets.symmetric(
          horizontal: 10,
          vertical: 6,
        ),
      ),
      direction: DismissDirection.endToStart,
      confirmDismiss: (direction) {
        return showDialog(
          context: context,
          builder: (ctx) => AlertDialog(
            content: Text(
              'Czy usunąć zapis z historii?',
            ),
            actions: <Widget>[
              FlatButton(
                child: Text(
                  'Nie',
                  style: TextStyle(color: Theme.of(context).accentColor),
                ),
                onPressed: () {
                  Navigator.of(ctx).pop(false);
                },
              ),
              FlatButton(
                child: Text(
                  'Tak',
                  style: TextStyle(color: Theme.of(context).accentColor),
                ),
                onPressed: () {
                  Navigator.of(ctx).pop(true);
                },
              ),
            ],
          ),
        );
      },
      onDismissed: (direction) {
        Provider.of<HistoryList>(context, listen: false).deleteItem(widget.id);
      },
      child: Semantics(
        label: "Wykryty alarm",
        hint: "Kliknij aby wyświetlic szczegóły lub dodać opis alarmu",
        child: Card(
          elevation: 8.0,
          margin: new EdgeInsets.symmetric(horizontal: 10.0, vertical: 6.0),
          child: Container(
            decoration: BoxDecoration(color: Theme.of(context).cardColor),
            child: Semantics(
              label: "Wykryty alarm.",
              hint: "Kliknij aby wyświetlić szczegóły lub dodać opis alarmu.",
              child: ListTile(
                onTap: () => {
                  Navigator.of(context)
                      .pushNamed(
                        AlarmDetailsScreen.routeName,
                        arguments: HistoryItem(widget.id, widget.dbValue,
                            widget.dateTime, widget.description),
                      )
                      // .then((onGoBack)),
                },
                dense: true,
                title: Semantics(
                    label: "Data wystąpienie alarmu:",
                    child: Text(
                      DateFormat('dd-MM-yyyy').format(widget.dateTime),
                      style: TextStyle(
                          color: Theme.of(context).accentColor,
                          fontWeight: FontWeight.bold,
                          fontSize: 16),
                    )),
                subtitle: Semantics(
                    label: "Godzina wystąpienie alarmu:",
                    child: Text(
                      DateFormat('HH:mm').format(widget.dateTime),
                      style: TextStyle(
                          color: Theme.of(context).accentColor, fontSize: 14),
                    )),
                leading: Container(
                  padding: EdgeInsets.only(right: 12.0),
                  decoration: new BoxDecoration(
                      border: new Border(
                          right: new BorderSide(
                              width: 1.0,
                              color: Theme.of(context).accentColor))),
                  child: Semantics(
                    label: "Natężenie dźwięku w decybelach:",
                    child: CircleAvatar(
                      backgroundColor: Theme.of(context).accentColor,
                      child: Text(
                        "${widget.dbValue}dB",
                        style: TextStyle(
                          fontSize: 13,
                          color: Theme.of(context).cardColor,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                  ),
                ),
                trailing: Container(
                  width: 105,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: <Widget>[
                      Semantics(
                        label: "Opis alarmu",
                        hint: "Kliknij dwukrotnie aby dodać opis alarmu",
                        child: IconButton(
                          alignment: Alignment.centerRight,
                          icon: widget.description == null ||
                                  widget.description == ""
                              ? Icon(Icons.keyboard_arrow_right,
                                  semanticLabel:
                                      'Kliknij dwukrotnie aby dodać opis alarmu')
                              : Icon(
                                  Icons.description,
                                  semanticLabel:
                                      'Opis alarmu dodany. Kliknij dwukrotnie aby wyświetlić lub edytować',
                                ),
                          onPressed: () => {
                            Navigator.of(context)
                                .pushNamed(
                                  AlarmDetailsScreen.routeName,
                                  arguments: HistoryItem(
                                      widget.id,
                                      widget.dbValue,
                                      widget.dateTime,
                                      widget.description),
                                )
                                // .then((onGoBack)),
                          },
                          color: Theme.of(context).accentColor,
                        ),
                      ),
                      // IconButton(
                      //   icon: Icon(Icons.delete),
                      //   onPressed: () async {
                      //     try {
                      //       await Provider.of<HistoryList>(context, listen: false)
                      //           .deleteItem(id);
                      //       scaffold.hideCurrentSnackBar();
                      //       scaffold.showSnackBar(
                      //         SnackBar(
                      //           content: Text(
                      //             'Zapis usunięty',
                      //             textAlign: TextAlign.center,
                      //           ),
                      //           duration: Duration(seconds: 2),
                      //           action: SnackBarAction(
                      //             label: 'COFNIJ',
                      //             onPressed: () {
                      //               print(id);
                      //               print(dbValue);
                      //               print(dateTime);
                      //               Provider.of<HistoryList>(context, listen: false)
                      //                   .addItem(id, dbValue, dateTime);
                      //             },
                      //           ),
                      //         ),
                      //       );
                      //     } catch (error) {
                      //       scaffold.showSnackBar(
                      //         SnackBar(
                      //           content: Text(
                      //             'Wystąpił błąd w trakcie usuwania. Spróbuj później.',
                      //           ),
                      //         ),
                      //       );
                      //     }
                      //   },
                      //   color: Theme.of(context).errorColor,
                      // ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
